Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(652)

Unified Diff: ui/file_manager/file_manager/foreground/js/file_manager_commands.js

Issue 1872223002: Add verbs API to file handlers. Modify the Chrome OS UI so that it displayes the internationalized … (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Move back to "open-with" for the id of the more actions dialog, as it breaks some browsers tests, a… Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/file_manager/file_manager/foreground/js/file_manager_commands.js
diff --git a/ui/file_manager/file_manager/foreground/js/file_manager_commands.js b/ui/file_manager/file_manager/foreground/js/file_manager_commands.js
index 4e8cea502820f144d8f62ab6d7b66a69cf048502..d3658301d913df00a9a97c0af779841d4034f9ee 100644
--- a/ui/file_manager/file_manager/foreground/js/file_manager_commands.js
+++ b/ui/file_manager/file_manager/foreground/js/file_manager_commands.js
@@ -1022,7 +1022,7 @@ CommandHandler.COMMANDS_['default-task'] = /** @type {Command} */ ({
});
/**
* Displays open with dialog for current selection.
* @type {Command}
*/
CommandHandler.COMMANDS_['open-with'] = /** @type {Command} */ ({
@@ -1033,7 +1033,7 @@ CommandHandler.COMMANDS_['open-with'] = /** @type {Command} */ ({
execute: function(event, fileManager) {
fileManager.taskController.getFileTasks().then(function(tasks) {
tasks.showTaskPicker(fileManager.ui.defaultTaskPicker,
- str('OPEN_WITH_BUTTON_LABEL'),
+ str('MORE_ACTIONS_BUTTON_LABEL'),
'',
function(task) {
tasks.execute(task.taskId);
@@ -1050,7 +1050,7 @@ CommandHandler.COMMANDS_['open-with'] = /** @type {Command} */ ({
* @param {!FileManager} fileManager FileManager to use.
*/
canExecute: function(event, fileManager) {
- var canExecute = fileManager.taskController.canExecuteOpenWith();
+ var canExecute = fileManager.taskController.canExecuteMoreActions();
event.canExecute = canExecute;
event.command.setHidden(!canExecute);
}
@@ -1022,7 +1022,7 @@ CommandHandler.COMMANDS_['default-task'] = /** @type {Command} */ ({
});
/**
- * Displays open with dialog for current selection.
+ * Displays "open with"/"more actions" dialog for current selection.
* @type {Command}
*/
« no previous file with comments | « third_party/closure_compiler/externs/file_manager_private.js ('k') | ui/file_manager/file_manager/foreground/js/file_tasks.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698